Installation and Getting Started
================================

.. note::

    When installing ``earthkit`` all the available components will be installed for you. If you only need certain components you can install them one by one.

Installing earthkit
----------------------------

Install **earthkit** with python3 (>= 3.10) and ``pip`` as follows (specific to version 1.0.0 release candidate):

.. code-block:: bash

    python3 -m pip install earthkit>=1.0.0rc0

.. Alternatively, install via ``conda`` with:

.. .. code-block:: bash

..     conda install earthkit -c conda-forge

.. This will bring in some necessary binary dependencies for you.
